LETypeUserFacing extension
- on
Properties
- isUserFacing → bool
-
Available on LEType, provided by the LETypeUserFacing extension
Returns true if this type is intended for user code.no setter
Available on LEType, provided by the LETypeUserFacing extension
Returns true if this type is intended for user code.