LEType enum
The type of a LaTeX element.
User-facing types are marked below. Internal types are for package use only.
- Inheritance
- Available extensions
Values
- trunk → const LEType
- node → const LEType
- leaf → const LEType
- numeratorNode → const LEType
- denominatorNode → const LEType
- indexOfRootNode → const LEType
- radicandNode → const LEType
- lowerLimitNode → const LEType
- upperLimitNode → const LEType
- integrandNode → const LEType
- summandNode → const LEType
- placeHolderLeaf → const LEType
- functionNode → const LEType
- inverseFunctionNode → const LEType
- fractionNode → const LEType
- squareRootNode → const LEType
- cubeRootNode → const LEType
- nthRootNode → const LEType
- powerNode → const LEType
- integralNode → const LEType
- summationNode → const LEType
- numberLeaf → const LEType
- operatorLeaf → const LEType
- variableLeaf → const LEType
- symbolLeaf → const LEType
- specialSymbolLeaf → const LEType
- textLeaf → const LEType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isUserFacing → bool
-
Available on LEType, provided by the LETypeUserFacing extension
Returns true if this type is intended for user code.no setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited